@@ -9,7 +9,7 @@ use parent 'Mail::Box::Search';
 use strict;
 use warnings;
 
-use Log::Report 'mail-box-imap4';
+use Log::Report 'mail-box-imap4', import => [];
 
 #--------------------
 =chapter NAME
